==> TCRAPI-0.1.0.tar.gz: TCRAPI-0.1.0/README.md <==
# TCRAPI
[![PyPI Version](https://img.shields.io/pypi/v/TCRAPI)](https://pypi.org/project/TCRAPI/)
[![Python Versions](https://img.shields.io/pypi/pyversions/TCRAPI)](https://pypi.org/project/TCRAPI/)

TCR API Interaction Library

## Usage

- **[QuickStart](docs/quickstart.md)**

- **[References](docs/references.md)**

- **[FastAPI](docs/FastAPI.md)**



## Install

### via pip ( recommended )

The easiest way to install the latest version from PyPI is by using [pip](https://pip.pypa.io/):

```$ pip install TCRAPI```

### via Git Clone *with extras* 

1. Clone the repository to an empty directory
    - ```$ git clone https://github.com/mitchellaha/TCRAPI.git .```
2. Create a virtual environment
    - ```$ python3 -m venv venv```
3. Activate the virtual environment
    - ```$ source venv/bin/activate```
4. Install dependencies
    - ```$ pip install -r requirements.txt```

### Build From Source ( *Advanced* )

1. Clone the repository to an empty directory
    - ```$ git clone https://github.com/mitchellaha/TCRAPI.git .```
2. Verify SetupTools is Updated
    - ```$ pip install --upgrade setuptools```
3. Install dependencies

-------------------

# To-Do:
- [ ] Add more documentation
- [x] Add Status Filter to Customers & Jobs
- [ ] *Create More Unified Filter Conditions*
    - [ ] GetSideMenus contains info for Quick Filter Check Boxes
    - [ ] Pull the needed data from the TCR_Menu/TCRConstants
    - [ ] Advanced Search Filters:
        - DataTypes = "QueryFilterFieldDataType" in TCRConstants
        - Each DataType is allowed certain "QueryParamOperator" in TCRConstants
- [ ] Add Ticket Status & Ticket Type Filter
- [x] Pagination Support
- [x] Cleanup Login / CookieGetter
- [ ] Serverside Logging
- [ ] Add Descript Response Error Messages
- [ ] Add Authentication

- [ ] **[All GetGridData](docs/quickstart.md)**

#### Other
- [x] Get Side Menus
- [ ] *Get Search Records*
- [x] Get Grid Columns For Advanced Search
- [ ] Customers Page
    - [ ] Get Tickets Count
    - [ ] Get Customer Overview
    - [ ] Get Billing History
    - [ ] Get Top 5 Equipment
- [ ] Get Audit Data
    - [ ] Customers
    - [ ] Jobs
    - [ ] Tickets

==> TCRAPI-0.1.1.tar.gz: TCRAPI-0.1.1/README.md <==
# TCRAPI
[![PyPI Version](https://img.shields.io/pypi/v/TCRAPI)](https://pypi.org/project/TCRAPI/)
[![Python Versions](https://img.shields.io/pypi/pyversions/TCRAPI)](https://pypi.org/project/TCRAPI/)

TCR API Interaction Library

## Usage

- **[QuickStart](docs/quickstart.md)**

- **[References](docs/references.md)**

- **[FastAPI](docs/FastAPI.md)**

- **[Release ChangeLog](docs/changelog.md)**



## Install

### via pip ( recommended )

The easiest way to install the latest version from PyPI is by using [pip](https://pip.pypa.io/):

```$ pip install TCRAPI```

### via Git Clone *with extras* 

1. Clone the repository to an empty directory
    - ```$ git clone https://github.com/mitchellaha/TCRAPI.git .```
2. Create a virtual environment
    - ```$ python3 -m venv venv```
3. Activate the virtual environment
    - ```$ source venv/bin/activate```
4. Install dependencies
    - ```$ pip install -r requirements.txt```

### From Source ( *Advanced* )

1. Clone the repository to an empty directory
    - ```$ git clone https://github.com/mitchellaha/TCRAPI.git .```
2. Verify SetupTools is Updated
    - ```$ pip install --upgrade setuptools```
3. Install the project
    - ```$ python setup.py install```


-------------------


## To-Do:
- [ ] **[All TCR API Endpoints](docs/TCREndpoints.md)**
- [ ] Add more documentation
    - [ ] Explain Correlation & Uses of different TCR Rest endpoints
- [ ] Complete Overhaul of TCRAPI/getgriddata/ grid classes
    - [ ] Create Base Class For All Grid Classes
    - [ ] Change Naming Scheme
- [ ] *Create More Unified Filter Conditions*
    - [x] ~~Add Status Filter to Customers & Jobs~~
    - [ ] GetSideMenus contains info for Quick Filter Check Boxes
        - [ ] Add Ticket Status & Ticket Type Filter
    - [ ] Pull the needed data from the TCR_Menu/TCRConstants
    - [ ] Advanced Search Filters:
        - [ ] Python Class Enums with TCRConstants
        - DataTypes = "QueryFilterFieldDataType" in TCRConstants
        - Each DataType is allowed certain "QueryParamOperator" in TCRConstants
- [x] Pagination Support
- [x] Cleanup Login / CookieGetter


- [ ] **[FastAPI](docs/FastAPI.md)**
    - [ ] Add Documentation
        - [ ] Add PostMan Collection
    - [ ] Add Authentication
    - [ ] Serverside Logging
    - [ ] Add Descript Error Messages
